@@ -6,6 +6,7 @@ APS GENERAL SUPPORT
 .. autosummary::
 
     ~ApsCycleComputedRO
+    ~ApsCycleDM
     ~ApsMachineParametersDevice
     ~ApsPssShutter
     ~ApsPssShutterWithStatus
@@ -176,8 +177,28 @@ def use_EPICS_scaler_channels(scaler):
         scaler.channels.configuration_attrs = configuration_attrs
 
 
-class ApsCycleComputedRO(SynSignalRO):
+class ApsCycleDM(SynSignalRO):
+    """
+    Get the APS cycle name from the APS Data Management system
 
+    This signal is read-only.
+    """
+
+    _time_last_updated = -1
+    _update_period_s = 60*60*24     # update from dm no more than daily
+    _cycle_name = "unknown"
+
+    def get(self):
+        from .beamtime.apsbss import getCurrentCycle
+        if time.time() > self._time_last_updated + self._update_period_s:
+            # only update from data management once per day
+            self._cycle_name = getCurrentCycle()
+            self._time_updated = time.time()
+            # TODO: could get the end time for current cycle and use that instead
+        return self._cycle_name
+
+
+class ApsCycleComputedRO(SynSignalRO):
     """
     Compute the APS cycle name based on the calendar and the usual practice.
 
@@ -187,7 +208,8 @@ class ApsCycleComputedRO(SynSignalRO):
 
     This signal is read-only.
 
-    NOTE: There is info provided by the APS proposal & ESAF systems.
+    NOTE: There is info provided by the APS proposal & ESAF systems.  See
+    :class:`~ApsCycleDM`.
     """
 
     def get(self):
@@ -197,7 +219,6 @@ class ApsCycleComputedRO(SynSignalRO):
 
 
 class ApsOperatorMessagesDevice(Device):
-
     """General messages from the APS main control room."""
 
     operators = Component(EpicsSignalRO, "OPS:message1", string=True)
@@ -212,7 +233,6 @@ class ApsOperatorMessagesDevice(Device):
 
 
 class ApsMachineParametersDevice(Device):
-
     """
     Common operational parameters of the APS of general interest.
 
@@ -242,7 +262,7 @@ class ApsMachineParametersDevice(Device):
     """
     current = Component(EpicsSignalRO, "S:SRcurrentAI")
     lifetime = Component(EpicsSignalRO, "S:SRlifeTimeHrsCC")
-    aps_cycle = Component(ApsCycleComputedRO)
+    aps_cycle = Component(ApsCycleDM)
     machine_status = Component(EpicsSignalRO, "S:DesiredMode", string=True)
     # In [3]: APS.machine_status.enum_strs
     # Out[3]:
@@ -297,7 +317,6 @@ class ApsMachineParametersDevice(Device):
 
 
 class ShutterBase(Device):
-
     """
     Base class for all shutter Devices.
 
@@ -511,7 +530,6 @@ class ShutterBase(Device):
 
 
 class OneSignalShutter(ShutterBase):
-
     """
     Shutter Device using one Signal for open and close.
 
@@ -607,7 +625,6 @@ class OneSignalShutter(ShutterBase):
 
 
 class ApsPssShutter(ShutterBase):
-
     """
     APS PSS shutter
 
@@ -701,7 +718,6 @@ class ApsPssShutter(ShutterBase):
 
 
 class ApsPssShutterWithStatus(ApsPssShutter):
-
     """
     APS PSS shutter with separate status PV
 
@@ -852,7 +868,6 @@ class ApsPssShutterWithStatus(ApsPssShutter):
 
 
 class SimulatedApsPssShutterWithStatus(ApsPssShutterWithStatus):
-
     """
     Simulated APS PSS shutter
 
@@ -907,7 +922,6 @@ class SimulatedApsPssShutterWithStatus(ApsPssShutterWithStatus):
 
 
 class ApsUndulator(Device):
-
     """
     APS Undulator
 
@@ -940,7 +954,6 @@ class ApsUndulator(Device):
 
 
 class ApsUndulatorDual(Device):
-
     """
     APS Undulator with upstream *and* downstream controls
 
@@ -956,7 +969,6 @@ class ApsUndulatorDual(Device):
 
 
 class ApsBssUserInfoDevice(Device):
-
     """
     Provide current experiment info from the APS BSS.
 
@@ -1080,7 +1092,6 @@ class AxisTunerMixin(DeviceMixinBase):
 
 
 class EpicsDescriptionMixin(DeviceMixinBase):
-
     """
     add a record's description field to a Device, such as EpicsMotor
 
@@ -1122,7 +1133,6 @@ class EpicsDescriptionMixin(DeviceMixinBase):
 
 
 class EpicsMotorDialMixin(DeviceMixinBase):
-
     """
     add motor record's dial coordinate fields to Device
 
@@ -1141,7 +1151,6 @@ class EpicsMotorDialMixin(DeviceMixinBase):
 
 
 class EpicsMotorEnableMixin(DeviceMixinBase):
-
     """
     mixin providing access to motor enable/disable
 
@@ -1183,7 +1192,6 @@ class EpicsMotorEnableMixin(DeviceMixinBase):
 
 
 class EpicsMotorLimitsMixin(DeviceMixinBase):
-
     """
     add motor record HLM & LLM fields & compatibility get_lim() and set_lim()
 
@@ -1261,7 +1269,6 @@ class EpicsMotorLimitsMixin(DeviceMixinBase):
 
 
 class EpicsMotorServoMixin(DeviceMixinBase):
-
     """
     add motor record's servo loop controls to Device
 
@@ -1280,7 +1287,6 @@ class EpicsMotorServoMixin(DeviceMixinBase):
 
 
 class EpicsMotorRawMixin(DeviceMixinBase):
-
     """
     add motor record's raw coordinate fields to Device
 
@@ -1298,7 +1304,6 @@ class EpicsMotorRawMixin(DeviceMixinBase):
 
 
 class EpicsMotorResolutionMixin(DeviceMixinBase):
-
     """
     Add motor record's resolution fields to motor.
 
@@ -1328,7 +1333,6 @@ class EpicsMotorResolutionMixin(DeviceMixinBase):
 
 
 class EpicsMotorShutter(OneSignalShutter):
-
     """
     a shutter, implemented with an EPICS motor moved between two positions
 
@@ -1387,7 +1391,6 @@ class EpicsMotorShutter(OneSignalShutter):
 
 
 class EpicsOnOffShutter(OneSignalShutter):
-
     """
     a shutter using a single EPICS PV moved between two positions
 
@@ -1415,7 +1418,6 @@ class EpicsOnOffShutter(OneSignalShutter):
 
 
 class DualPf4FilterBox(Device):
-
     """
     Dual Xia PF4 filter boxes using support from synApps (using Al, Ti foils)
 
@@ -1445,7 +1447,6 @@ class DualPf4FilterBox(Device):
 
 
 class KohzuSeqCtl_Monochromator(Device):
-
     """
     synApps Kohzu double-crystal monochromator sequence control program
     """
@@ -1454,12 +1455,14 @@ class KohzuSeqCtl_Monochromator(Device):
     wavelength = Component(EpicsSignal, "BraggLambdaRdbkAO", write_pv="BraggLambdaAO")
     energy = Component(EpicsSignal, "BraggERdbkAO", write_pv="BraggEAO")
     theta = Component(EpicsSignal, "BraggThetaRdbkAO", write_pv="BraggThetaAO")
-    message1 = Component(EpicsSignalRO, "KohzuSeqMsg1SI")
+    y1 = Component(EpicsSignalRO, "KohzuYRdbkAI")
+    z2 = Component(EpicsSignalRO, "KohzuZRdbkAI")
     message2 = Component(EpicsSignalRO, "KohzuSeqMsg2SI")
     operator_acknowledge = Component(EpicsSignal, "KohzuOperAckBO")
     use_set = Component(EpicsSignal, "KohzuUseSetBO")
     mode = Component(EpicsSignal, "KohzuModeBO")
     move_button = Component(EpicsSignal, "KohzuPutBO")
+    moving = Component(EpicsSignal, "KohzuMoving")
     y_offset = Component(EpicsSignal, "Kohzu_yOffsetAO")
 
     crystal_mode = Component(EpicsSignal, "KohzuMode2MO")
@@ -1470,9 +1473,13 @@ class KohzuSeqCtl_Monochromator(Device):
     crystal_2d_spacing = Component(EpicsSignal, "Bragg2dSpacingAO")
     crystal_type = Component(EpicsSignal, "BraggTypeMO")
 
+    def move_energy(self, energy):
+        """for command-line use:  ``kohzu_mono.energy_move(8.2)``"""
+        self.energy.put(energy)
+        self.move_button.put(1)
+
 
 class ProcessController(Device):
-
     """
     common parts of a process controller support
 
@@ -1611,7 +1618,6 @@ class ProcessController(Device):
 
 
 class Struck3820(Device):
-
     """Struck/SIS 3820 Multi-Channel Scaler (as used by USAXS)"""
 
     start_all = Component(EpicsSignal, "StartAll")
@@ -1739,7 +1745,6 @@ def AD_warmed_up(detector):
 
 
 class AD_EpicsHdf5FileName(FileStorePluginBase):    # lgtm [py/missing-call-to-init]
-
     """
     custom class to define image file name from EPICS
 
